@@ -1,38 +1,36 @@
-import shlex
 import asyncio
+import shlex
 from asyncio import TimerHandle
 from dataclasses import dataclass
-from typing import Dict, List, Optional, NoReturn, Union
+from typing import Dict, List, NoReturn, Optional, Union
 
-from nonebot.matcher import Matcher
-from nonebot.exception import ParserExit
-from nonebot.plugin import PluginMetadata
-from nonebot.rule import Rule, ArgumentParser
 from nonebot import on_command, on_shell_command, require
-from nonebot.params import EventToMe, CommandArg, CommandStart, ShellCommandArgv
-
 from nonebot.adapters.onebot.v11 import Bot as V11Bot
-from nonebot.adapters.onebot.v11 import Message as V11Msg
-from nonebot.adapters.onebot.v11 import MessageSegment as V11MsgSeg
-from nonebot.adapters.onebot.v11 import MessageEvent as V11MEvent
 from nonebot.adapters.onebot.v11 import GroupMessageEvent as V11GMEvent
+from nonebot.adapters.onebot.v11 import Message as V11Msg
+from nonebot.adapters.onebot.v11 import MessageEvent as V11MEvent
+from nonebot.adapters.onebot.v11 import MessageSegment as V11MsgSeg
 from nonebot.adapters.onebot.v11 import PrivateMessageEvent as V11PMEvent
-
 from nonebot.adapters.onebot.v12 import Bot as V12Bot
-from nonebot.adapters.onebot.v12 import Message as V12Msg
-from nonebot.adapters.onebot.v12 import MessageSegment as V12MsgSeg
-from nonebot.adapters.onebot.v12 import MessageEvent as V12MEvent
-from nonebot.adapters.onebot.v12 import GroupMessageEvent as V12GMEvent
-from nonebot.adapters.onebot.v12 import PrivateMessageEvent as V12PMEvent
 from nonebot.adapters.onebot.v12 import ChannelMessageEvent as V12CMEvent
+from nonebot.adapters.onebot.v12 import GroupMessageEvent as V12GMEvent
+from nonebot.adapters.onebot.v12 import Message as V12Msg
+from nonebot.adapters.onebot.v12 import MessageEvent as V12MEvent
+from nonebot.adapters.onebot.v12 import MessageSegment as V12MsgSeg
+from nonebot.adapters.onebot.v12 import PrivateMessageEvent as V12PMEvent
+from nonebot.exception import ParserExit
+from nonebot.matcher import Matcher
+from nonebot.params import CommandArg, CommandStart, EventToMe, ShellCommandArgv
+from nonebot.plugin import PluginMetadata
+from nonebot.rule import ArgumentParser, Rule
 
 require("nonebot_plugin_datastore")
 require("nonebot_plugin_htmlrender")
 
+from .game import Game, MoveResult, Player, Pos
 from .go import Go
 from .gomoku import Gomoku
 from .othello import Othello
-from .game import Game, MoveResult, Player, Pos
 
 __plugin_meta__ = PluginMetadata(
     name="棋类游戏",
@@ -46,7 +44,7 @@ __plugin_meta__ = PluginMetadata(
         "unique_name": "boardgame",
         "example": "@小Q 五子棋\n落子 G8\n结束下棋",
         "author": "meetwq <meetwq@gmail.com>",
-        "version": "0.2.0",
+        "version": "0.2.1",
     },
 )
 
